///////////////////////////////////////////////////////////////////
//
// Project RENOIR
// Release Notes Instant Reporter
//
// Reference application presented in
// Clean Architecture with .NET (MS Press) 2024
// Author: Dino Esposito
// 
//


using System.ComponentModel.DataAnnotations;
using Youbiquitous.Renoir.DomainModel.Management;

namespace Youbiquitous.Renoir.DomainModel;

/// <summary>
/// USER/PRODUCT binding (properties)
/// </summary>
public partial class UserProductBinding : BaseEntity
{
    /// <summary>
    /// Ctor, mostly needed for EF and to save us an entire layer of DTOs
    /// </summary>
    public UserProductBinding()
    {
    }

    public UserProductBinding(long productId, long userId = 0, string role = Role.NameOf_Viewer)
    {
        ProductId = productId;
        UserId = userId;
        RoleId = role;
    }
    
    /// <summary>
    /// Unique ID (autogenerated)
    /// </summary>
    public long RefId { get; set; }

    /// <summary>
    /// Product ID
    /// </summary>
    public long ProductId { get; set; }
    public Product RelatedProduct { get; set; }

    /// <summary>
    /// User ID
    /// </summary>
    public long UserId { get; set; }
    public User RelatedUser { get; set; }

    /// <summary>
    /// Role for the user
    /// </summary>
    [MaxLength(50)]
    public string RoleId { get; set; }
}
